port module Parse exposing (..)

import Html exposing (Html)
import SvgAst exposing (SvgAst)
import SvgAst.Parser exposing (parse)
import SvgAst.Render exposing (render)
import Maybe
import Element exposing (show, toHtml)
import Result as R
import List exposing (map)

type Msg = NoOp

type alias Model =
    {
      svgParsed : Maybe SvgAst
    }

initialModel : Model
initialModel =
    {
      svgParsed = Nothing
    }

svgString : String
svgString =
    """
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!-- Created with Inkscape (http://www.inkscape.org/) -->

<svg
   xmlns:dc="http://purl.org/dc/elements/1.1/"
   xmlns:cc="http://creativecommons.org/ns#"
   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
   xmlns:svg="http://www.w3.org/2000/svg"
   xmlns="http://www.w3.org/2000/svg"
   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
   width="767.57739"
   height="696.12714"
   id="svg2"
   version="1.1"
   inkscape:version="0.48.0 r9654"
   sodipodi:docname="Cute">
  <defs
     id="defs4">
    <filter
       id="InvertTransparencyBitmapFilter"
       color-interpolation-filters="sRGB">
      <feComponentTransfer
         id="feComponentTransfer3040">
        <feFuncR
           id="feFuncR3042"
           offset="-0.055"
           exponent=".416666666"
           amplitude="1.055"
           type="gamma" />
        <feFuncG
           id="feFuncG3044"
           offset="-0.055"
           exponent=".416666666"
           amplitude="1.055"
           type="gamma" />
        <feFuncB
           id="feFuncB3046"
           offset="-0.055"
           exponent=".416666666"
           amplitude="1.055"
           type="gamma" />
      </feComponentTransfer>
      <feComponentTransfer
         id="feComponentTransfer3048">
        <feFuncR
           id="feFuncR3050"
           intercept="1"
           slope="-1"
           type="linear" />
        <feFuncG
           id="feFuncG3052"
           intercept="1"
           slope="-1"
type="linear" />
        <feFuncB
           id="feFuncB3054"
           intercept="1"
           slope="-1"
           type="linear" />
        <feFuncA
           id="feFuncA3056"
           intercept="0"
           slope="1"
           type="linear" />
      </feComponentTransfer>
      <feComponentTransfer
         id="feComponentTransfer3058">
        <feFuncR
           id="feFuncR3060"
           offset="0"
           exponent="2.4"
           amplitude="1"
           type="gamma" />
        <feFuncG
           id="feFuncG3062"
           offset="0"
           exponent="2.4"
           amplitude="1"
           type="gamma" />
        <feFuncB
           id="feFuncB3064"
           offset="0"
           exponent="2.4"
           amplitude="1"
           type="gamma" />
      </feComponentTransfer>
    </filter>
    <filter
       id="BleachFilter"
       color-interpolation-filters="sRGB">
      <feBlend
         id="feBlend3035"
         result="blend"
         in="SourceGraphic"
         in2="BackgroundImage"
         mode="screen" />
      <feComposite
         id="feComposite3037"
         result="comp"
         operator="in"
         in2="SourceAlpha"
         in="blend" />
    </filter>
    <filter
       id="StainedFilter"
       color-interpolation-filters="sRGB">
      <feBlend
id="feBlend3030"
         result="blend"
         in="SourceGraphic"
         in2="BackgroundImage"
         mode="multiply" />
      <feComposite
         id="feComposite3032"
         result="comp"
         operator="in"
         in2="SourceAlpha"
         in="blend" />
    </filter>
    <marker
       orient="auto"
       overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow9"
       style="overflow:visible">
      <!-- REF_ARROW_HOLLOWDIAMOND -->
      <g
         id="g3025"
         transform="scale(0.00925926,0.00925926)">
        <path
           id="path3027"
           d="M 0,45 -45,0 0,-45 45,0 z M 0,63 -63,0 0,-63 63,0 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
    <marker
       orient="auto"
       overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow8"
       style="overflow:visible">
      <!-- REF_ARROW_FEATHER2 -->
      <g
         id="g3020"
         transform="scale(0.00925926,0.00925926)">
        <path
           id="path3022"
           d="m -36,0 54,-54 36,0 -36,36 9,0 36,-36 36,0 -36,36 9,0 36,-36 36,0 -54,54 54,54 -36,0 -36,-36 -9,0 36,36 -36,0 -36,-36 -9,0 36,36 -36,0 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
    <marker
       orient="auto"
overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow7"
       style="overflow:visible">
      <!-- REF_ARROW_FEATHER -->
      <g
         id="g3015"
         transform="scale(0.00925926,0.00925926)">
        <path
           id="path3017"
           d="m 18,-54 90,0 L 63,0 108,54 18,54 -36,0 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
    <marker
       orient="auto"
       overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow6"
       style="overflow:visible">
      <!-- REF_ARROW_DIAMOND -->
      <g
         id="g3010"
         transform="scale(0.00925926,0.00925926)">
        <path
           id="path3012"
           d="M -63,0 0,63 63,0 0,-63 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
    <marker
       orient="auto"
       overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow5"
       style="overflow:visible">
      <!-- REF_ARROW_SPOT -->
      <g
         id="g3005"
         transform="scale(0.00925926,0.00925926)">
        <path
           id="path3007"
           d="M -54,0 C -54,29.807 -29.807,54 0,54 29.807,54 54,29.807 54,0 54,-29.807 29.807,-54 0,-54 -29.807,-54 -54,-29.807 -54,0 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
    <marker
       orient="auto"
       overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow4"
       style="overflow:visible">
      <!-- REF_ARROW_ROUNDED -->
      <g
         id="g3000"
         transform="scale(0.00925926,0.00925926)">
        <path
           id="path3002"
           d="m -9,0 0,-45 c 0,-6.708 11.808,-11.58 18,-9 l 108,45 c 3.916,1.631 9,4.758 9,9 0,4.242 -5.084,7.369 -9,9 L 9,54 C 2.808,56.58 -9,51.708 -9,45 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
    <marker
       orient="auto"
       overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow3"
       style="overflow:visible">
      <!-- REF_ARROW_ANGLED -->
      <g
         id="g2995"
         transform="scale(0.00925926,0.00925926)">
        <path
           id="path2997"
           d="M -27,54 -9,0 -27,-54 135,0 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
    <marker
       orient="auto"
       overflow="visible"
       markerHeight="1"
       markerWidth="1"
       viewBox="0 0 1 1"
       markerUnits="strokeWidth"
       id="DefaultArrow2"
       style="overflow:visible">
      <!-- REF_ARROW_STRAIGHT (-2) -->
      <g
         id="g2990"
         transform="scale(0.00925926,0.00925926)">
        <!-- 1/108 -->
        <path
           id="path2992"
           d="M -9,54 -9,-54 117,0 z"
           inkscape:connector-curvature="0" />
      </g>
    </marker>
  </defs>
  <sodipodi:namedview
     id="base"
     pagecolor="#ffffff"
     bordercolor="#666666"
     borderopacity="1.0"
     inkscape:pageopacity="0.0"
     inkscape:pageshadow="2"
     inkscape:zoom="0.35"
     inkscape:cx="236.64587"
     inkscape:cy="226.63501"
     inkscape:document-units="px"
     inkscape:current-layer="layer1"
     showgrid="false"
     inkscape:window-width="1280"
     inkscape:window-height="744"
     inkscape:window-x="-4"
     inkscape:window-y="-4"
     inkscape:window-maximized="1"
     fit-margin-top="0"
     fit-margin-left="0"
     fit-margin-right="0"
     fit-margin-bottom="0" />
  <metadata
     id="metadata7">
    <rdf:RDF>
      <cc:Work
         rdf:about="">
        <dc:format>image/svg+xml</dc:format>
        <dc:type
           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
        <dc:title></dc:title>
      </cc:Work>
    </rdf:RDF>
  </metadata>
  <g
     inkscape:label="Capa 1"
     inkscape:groupmode="layer"
     id="layer1"
     transform="translate(-113.35413,-62.870073)">
    <g
       transform="matrix(1.1095535,0,0,-1.1687058,83.615661,8.9179464)"
       font-size="16"
       id="Document"
       style="font-size:16px;fill:none;stroke:#000000;stroke-width:1.09769905;font-family:Times New Roman">
      <g
         transform="translate(0,-678.686)"
         id="Spread"
         style="stroke-width:1.09769905">
        <g
           id="Layer 1"
           style="stroke-width:1.09769905">
          <g
             id="Group"
             style="stroke:none">
            <ellipse
               id="ellipse3070"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(-0.55347877,0.83286329,-0.83286329,-0.55347877,133.272,532.224)"
               ry="116.823"
               rx="77.990997"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="77.990997"
               sodipodi:ry="116.823"
               style="fill:#402100"
               d="M 77.990997,0 C 77.990997,64.51956 43.073238,116.823 0,116.823 -43.073238,116.823 -77.990997,64.51956 -77.990997,0 c 0,-64.51956 34.917759,-116.823 77.990997,-116.823 43.073238,0 77.990997,52.30344 77.990997,116.823 z" />
            <ellipse
               id="ellipse3072"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(-0.55349331,0.83285362,-0.83285362,-0.55349331,136.751,527.925)"
               ry="105.4"
               rx="70.363998"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="70.363998"
               sodipodi:ry="105.4"
               style="fill:#7f4100"
               d="M 70.363998,0 C 70.363998,58.210813 38.860963,105.4 0,105.4 -38.860963,105.4 -70.363998,58.210813 -70.363998,0 c 0,-58.210813 31.503035,-105.4 70.363998,-105.4 38.860963,0 70.363998,47.189187 70.363998,105.4 z" />
            <ellipse
               id="ellipse3074"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(-0.55347877,0.83286329,-0.83286329,-0.55347877,139.773,520.712)"
               ry="93.016998"
               rx="62.098"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="62.098"
               sodipodi:ry="93.016998"
               style="fill:#a95b09"
               d="M 62.098,0 C 62.098,51.37187 34.295778,93.016998 0,93.016998 -34.295778,93.016998 -62.098,51.37187 -62.098,0 c 0,-51.37187 27.802222,-93.016998 62.098,-93.016998 34.295778,0 62.098,41.645128 62.098,93.016998 z" />
            <ellipse
               id="ellipse3076"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(-0.55349331,0.83285362,-0.83285362,-0.55349331,144.443,519.63)"
               ry="61.397999"
               rx="40.988998"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="40.988998"
               sodipodi:ry="61.397999"
               style="fill:#c5731d"
               d="M 40.988998,0 C 40.988998,33.909178 22.637599,61.397999 0,61.397999 -22.637599,61.397999 -40.988998,33.909178 -40.988998,0 c 0,-33.909178 18.351399,-61.397999 40.988998,-61.397999 22.637599,0 40.988998,27.488821 40.988998,61.397999 z" />
          </g>
          <g
             id="Group_1"
             style="stroke:none">
            <ellipse
               id="ellipse3079"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0.55348313,0.83286039,-0.83286039,0.55348313,612.122,540.87)"
               ry="116.823"
               rx="77.990997"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="77.990997"
               sodipodi:ry="116.823"
               style="fill:#402100"
               d="M 77.990997,0 C 77.990997,64.51956 43.073238,116.823 0,116.823 -43.073238,116.823 -77.990997,64.51956 -77.990997,0 c 0,-64.51956 34.917759,-116.823 77.990997,-116.823 43.073238,0 77.990997,52.30344 77.990997,116.823 z" />
            <ellipse
               id="ellipse3081"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0.55348604,0.83285846,-0.83285846,0.55348604,608.641,536.571)"
               ry="105.4"
               rx="70.363998"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="70.363998"
               sodipodi:ry="105.4"
               style="fill:#7f4100"
               d="M 70.363998,0 C 70.363998,58.210813 38.860963,105.4 0,105.4 -38.860963,105.4 -70.363998,58.210813 -70.363998,0 c 0,-58.210813 31.503035,-105.4 70.363998,-105.4 38.860963,0 70.363998,47.189187 70.363998,105.4 z" />
            <ellipse
               id="ellipse3083"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0.55347296,0.83286715,-0.83286715,0.55347296,605.621,529.359)"
               ry="93.016998"
               rx="62.098"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="62.098"
               sodipodi:ry="93.016998"
               style="fill:#a95b09"
               d="M 62.098,0 C 62.098,51.37187 34.295778,93.016998 0,93.016998 -34.295778,93.016998 -62.098,51.37187 -62.098,0 c 0,-51.37187 27.802222,-93.016998 62.098,-93.016998 34.295778,0 62.098,41.645128 62.098,93.016998 z" />
            <ellipse
               id="ellipse3085"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0.55348894,0.83285652,-0.83285652,0.55348894,600.951,528.276)"
               ry="61.397999"
               rx="40.988998"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="40.988998"
               sodipodi:ry="61.397999"
               style="fill:#c5731d"
               d="M 40.988998,0 C 40.988998,33.909178 22.637599,61.397999 0,61.397999 -22.637599,61.397999 -40.988998,33.909178 -40.988998,0 c 0,-33.909178 18.351399,-61.397999 40.988998,-61.397999 22.637599,0 40.988998,27.488821 40.988998,61.397999 z" />
          </g>
          <path
             id="path3087"
             stroke-miterlimit="79.8403193612775"
             d="m 570.817,497.446 c -0.158,0.151 -0.314,0.252 -0.444,0.428 -0.115,0.153 -0.139,0.291 -0.221,0.465 -0.863,1.819 -1.409,3.817 -1.829,5.852 -0.412,1.991 -0.696,4.039 -0.857,6.158 -0.231,3.024 -0.165,6.25 0.161,9.191 0.574,5.191 1.942,10.036 4.173,14.408 0.943,1.849 2.03,3.626 3.316,5.304 0.706,0.922 1.466,1.815 2.292,2.68 3.697,3.874 8.125,6.485 13.15,7.737 2.586,0.644 5.54,0.915 8.43,0.669 1.984,-0.17 3.87,-0.521 5.67,-1.06 5.868,-1.759 10.949,-5.11 15.386,-9.697 0.616,-0.638 1.205,-1.289 1.772,-1.951 3.636,-4.248 6.429,-8.959 8.431,-14.029 0.49,-1.242 0.936,-2.521 1.278,-3.83 0.154,-0.592 0.285,-1.185 0.378,-1.806 0.027,-0.188 0.07,-0.343 0.079,-0.532 0.004,-0.089 0.044,-0.178 0.04,-0.266 -0.005,-0.107 -0.053,-0.209 -0.067,-0.315 -0.056,-0.421 -0.178,-0.842 -0.265,-1.257 -0.278,0.157 -0.556,0.315 -0.833,0.474 -0.206,0.117 -0.369,0.169 -0.555,0.316 -0.069,0.053 -0.112,0.136 -0.175,0.196 -0.251,0.233 -0.479,0.525 -0.699,0.787 -0.643,0.763 -1.234,1.567 -1.826,2.358 -0.795,1.061 -1.582,2.12 -2.382,3.177 -2.715,3.578 -5.68,7.105 -9.124,10.246 -3.41,3.107 -7.144,5.593 -11.334,7.137 -2.261,0.832 -4.716,1.371 -7.384,1.371 -6.008,0 -10.856,-2.576 -14.738,-6.771 -0.764,-0.825 -1.454,-1.697 -2.089,-2.584 -2.467,-3.444 -4.114,-7.317 -5.299,-11.402 -0.769,-2.65 -1.314,-5.402 -1.715,-8.242 -0.386,-2.726 -0.607,-5.532 -0.79,-8.359 -0.08,-1.234 -0.144,-2.468 -0.249,-3.691 -0.05,-0.572 -0.108,-1.147 -0.192,-1.701 -0.027,-0.176 -0.033,-0.325 -0.076,-0.497 -0.021,-0.081 -0.01,-0.17 -0.037,-0.248 -0.034,-0.097 -0.102,-0.179 -0.142,-0.272 -0.162,-0.371 -0.38,-0.728 -0.566,-1.086 -0.223,0.213 -0.446,0.428 -0.668,0.642 z"
             inkscape:connector-curvature="0"
             style="fill:#402100;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
          <g
             id="Group_2"
             style="stroke:none">
            <g
               id="Group_3">
              <ellipse
                 id="ellipse3091"
                 stroke-miterlimit="79.8403193612775"
                 transform="matrix(0,1,-1,0,376.613,334.416)"
                 ry="280.026"
                 rx="234.392"
                 cx="0"
                 cy="0"
                 sodipodi:cx="0"
                 sodipodi:cy="0"
                 sodipodi:rx="234.392"
                 sodipodi:ry="280.026"
                 style="fill:#402100"
                 d="M 234.392,0 C 234.392,154.65409 129.45113,280.026 0,280.026 -129.45113,280.026 -234.392,154.65409 -234.392,0 c 0,-154.65409 104.94087,-280.026 234.392,-280.026 129.45113,0 234.392,125.37191 234.392,280.026 z" />
              <ellipse
                 id="ellipse3093"
                 stroke-miterlimit="79.8403193612775"
                 transform="matrix(-3.1415927e-5,1,-1,-3.1415927e-5,376.13,326.576)"
                 ry="262.258"
                 rx="227.998"
                 cx="0"
                 cy="0"
                 sodipodi:cx="0"
                 sodipodi:cy="0"
                 sodipodi:rx="227.998"
                 sodipodi:ry="262.258"
                 style="fill:#7f4100"
                 d="M 227.998,0 C 227.998,144.84109 125.91982,262.258 0,262.258 -125.91982,262.258 -227.998,144.84109 -227.998,0 c 0,-144.84109 102.07818,-262.258 227.998,-262.258 125.91982,0 227.998,117.41691 227.998,262.258 z" />
              <ellipse
                 id="ellipse3095"
                 stroke-miterlimit="79.8403193612775"
                 transform="matrix(-3.3161256e-5,1,-1,-3.3161256e-5,377.164,326.563)"
                 ry="232.181"
                 rx="216.74899"
                 cx="0"
                 cy="0"
                 sodipodi:cx="0"
                 sodipodi:cy="0"
                 sodipodi:rx="216.74899"
                 sodipodi:ry="232.181"
                 style="fill:#a95b09"
                 d="M 216.74899,0 C 216.74899,128.23003 119.70716,232.181 0,232.181 -119.70716,232.181 -216.74899,128.23003 -216.74899,0 c 0,-128.23003 97.04183,-232.181 216.74899,-232.181 119.70716,0 216.74899,103.95097 216.74899,232.181 z" />
            </g>
            <ellipse
               id="ellipse3097"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(-7.3303829e-5,1,-1,-7.3303829e-5,382.642,416.206)"
               ry="164.83299"
               rx="94.681"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="94.681"
               sodipodi:ry="164.83299"
               style="fill:#a05508"
               d="M 94.681,0 C 94.681,91.034748 52.290872,164.83299 0,164.83299 -52.290872,164.83299 -94.681,91.034748 -94.681,0 c 0,-91.034748 42.390128,-164.83299 94.681,-164.83299 52.290872,0 94.681,73.798242 94.681,164.83299 z" />
          </g>
          <ellipse
             id="ellipse3099"
             stroke-miterlimit="79.8403193612775"
             transform="matrix(-4.5378561e-5,1,-1,-4.5378561e-5,375.579,254.164)"
             ry="202.23199"
             rx="155.81799"
             cx="0"
             cy="0"
             sodipodi:cx="0"
             sodipodi:cy="0"
             sodipodi:rx="155.81799"
             sodipodi:ry="202.23199"
             style="fill:#ffc17f;stroke:none"
             d="M 155.81799,0 C 155.81799,111.68965 86.055901,202.23199 0,202.23199 -86.055901,202.23199 -155.81799,111.68965 -155.81799,0 c 0,-111.68965 69.762089,-202.23199 155.81799,-202.23199 86.055901,0 155.81799,90.54234 155.81799,202.23199 z" />
          <ellipse
             id="ellipse3101"
             stroke-miterlimit="79.8403193612775"
             transform="matrix(-4.712389e-5,1,-1,-4.712389e-5,375.093,252.976)"
             ry="188.62199"
             rx="146.101"
             cx="0"
             cy="0"
             sodipodi:cx="0"
             sodipodi:cy="0"
             sodipodi:rx="146.101"
             sodipodi:ry="188.62199"
             style="fill:#fcd5ad;stroke:none"
             d="M 146.101,0 C 146.101,104.17305 80.689353,188.62199 0,188.62199 -80.689353,188.62199 -146.101,104.17305 -146.101,0 c 0,-104.17305 65.411647,-188.62199 146.101,-188.62199 80.689353,0 146.101,84.44894 146.101,188.62199 z" />
          <ellipse
             id="ellipse3103"
             stroke-miterlimit="79.8403193612775"
             transform="matrix(-5.0614548e-5,1,-1,-5.0614548e-5,378.215,253.029)"
             ry="174.121"
             rx="139.36099"
             cx="0"
             cy="0"
             sodipodi:cx="0"
             sodipodi:cy="0"
             sodipodi:rx="139.36099"
             sodipodi:ry="174.121"
             style="fill:#fadec1;stroke:none"
             d="M 139.36099,0 C 139.36099,96.164374 76.966951,174.121 0,174.121 -76.966951,174.121 -139.36099,96.164374 -139.36099,0 c 0,-96.164374 62.394039,-174.121 139.36099,-174.121 76.966951,0 139.36099,77.956626 139.36099,174.121 z" />
          <ellipse
             id="ellipse3105"
             stroke-miterlimit="79.8403193612775"
             transform="matrix(-6.4577182e-5,1,-1,-6.4577182e-5,379.775,256.142)"
             ry="155.87199"
             rx="140.994"
             cx="0"
             cy="0"
             sodipodi:cx="0"
             sodipodi:cy="0"
             sodipodi:rx="140.994"
             sodipodi:ry="155.87199"
             style="fill:#fcd5ad;stroke:none"
             d="M 140.994,0 C 140.994,86.085725 77.868838,155.87199 0,155.87199 -77.868838,155.87199 -140.994,86.085725 -140.994,0 c 0,-86.085725 63.125162,-155.87199 140.994,-155.87199 77.868838,0 140.994,69.786265 140.994,155.87199 z" />
          <g
             id="Group_4"
             style="stroke:none">
            <ellipse
               id="ellipse3108"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,306.628,436.361)"
               ry="37.466"
               rx="33.782001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="33.782001"
               sodipodi:ry="37.466"
               style="fill:#000000"
               d="M 33.782001,0 C 33.782001,20.6919 18.657284,37.466 0,37.466 -18.657284,37.466 -33.782001,20.6919 -33.782001,0 c 0,-20.6919 15.124717,-37.466 33.782001,-37.466 18.657284,0 33.782001,16.7741 33.782001,37.466 z" />
            <ellipse
               id="ellipse3110"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,306.637,436.071)"
               ry="30.867001"
               rx="27.830999"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="27.830999"
               sodipodi:ry="30.867001"
               style="fill:#402100"
               d="M 27.830999,0 C 27.830999,17.047374 15.370637,30.867001 0,30.867001 -15.370637,30.867001 -27.830999,17.047374 -27.830999,0 c 0,-17.047374 12.460362,-30.867001 27.830999,-30.867001 15.370637,0 27.830999,13.819627 27.830999,30.867001 z" />
            <ellipse
               id="ellipse3112"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,306.867,435.962)"
               ry="25.200001"
               rx="22.721001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="22.721001"
               sodipodi:ry="25.200001"
               style="fill:#7f4100"
               d="M 22.721001,0 C 22.721001,13.917576 12.548462,25.200001 0,25.200001 -12.548462,25.200001 -22.721001,13.917576 -22.721001,0 c 0,-13.917576 10.172539,-25.200001 22.721001,-25.200001 12.548462,0 22.721001,11.282425 22.721001,25.200001 z" />
            <ellipse
               id="ellipse3114"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,307.409,435.766)"
               ry="16.698999"
               rx="15.056"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="15.056"
               sodipodi:ry="16.698999"
               style="fill:#000000"
               d="M 15.056,0 C 15.056,9.2226027 8.3151991,16.698999 0,16.698999 -8.3151991,16.698999 -15.056,9.2226027 -15.056,0 c 0,-9.2226027 6.7408009,-16.698999 15.056,-16.698999 8.3151991,0 15.056,7.4763963 15.056,16.698999 z" />
            <ellipse
               id="ellipse3116"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,295.616,448.789)"
               ry="9.2309999"
               rx="8.323"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="8.323"
               sodipodi:ry="9.2309999"
               style="fill:#ffffff"
               d="M 8.323,0 C 8.323,5.0981405 4.5966659,9.2309999 0,9.2309999 -4.5966659,9.2309999 -8.323,5.0981405 -8.323,0 c 0,-5.0981405 3.7263341,-9.2309999 8.323,-9.2309999 4.5966659,0 8.323,4.1328594 8.323,9.2309999 z" />
            <ellipse
               id="ellipse3118"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,324.754,433.356)"
               ry="5.7420001"
               rx="5.177"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="5.177"
               sodipodi:ry="5.7420001"
               style="fill:#ffffff"
               d="M 5.177,0 C 5.177,3.1712191 2.8591782,5.7420001 0,5.7420001 -2.8591782,5.7420001 -5.177,3.1712191 -5.177,0 c 0,-3.1712191 2.3178218,-5.7420001 5.177,-5.7420001 2.8591782,0 5.177,2.570781 5.177,5.7420001 z" />
            <ellipse
               id="ellipse3120"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,450.03,435.719)"
               ry="37.466"
               rx="33.782001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="33.782001"
               sodipodi:ry="37.466"
               style="fill:#000000"
               d="M 33.782001,0 C 33.782001,20.6919 18.657284,37.466 0,37.466 -18.657284,37.466 -33.782001,20.6919 -33.782001,0 c 0,-20.6919 15.124717,-37.466 33.782001,-37.466 18.657284,0 33.782001,16.7741 33.782001,37.466 z" />
            <ellipse
               id="ellipse3122"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,450.035,435.429)"
               ry="30.867001"
               rx="27.830999"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="27.830999"
               sodipodi:ry="30.867001"
               style="fill:#402100"
               d="M 27.830999,0 C 27.830999,17.047374 15.370637,30.867001 0,30.867001 -15.370637,30.867001 -27.830999,17.047374 -27.830999,0 c 0,-17.047374 12.460362,-30.867001 27.830999,-30.867001 15.370637,0 27.830999,13.819627 27.830999,30.867001 z" />
            <ellipse
               id="ellipse3124"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,450.268,435.321)"
               ry="25.200001"
               rx="22.721001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="22.721001"
               sodipodi:ry="25.200001"
               style="fill:#7f4100"
               d="M 22.721001,0 C 22.721001,13.917576 12.548462,25.200001 0,25.200001 -12.548462,25.200001 -22.721001,13.917576 -22.721001,0 c 0,-13.917576 10.172539,-25.200001 22.721001,-25.200001 12.548462,0 22.721001,11.282425 22.721001,25.200001 z" />
            <ellipse
               id="ellipse3126"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,450.811,435.124)"
               ry="16.698999"
               rx="15.056"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="15.056"
               sodipodi:ry="16.698999"
               style="fill:#000000"
               d="M 15.056,0 C 15.056,9.2226027 8.3151991,16.698999 0,16.698999 -8.3151991,16.698999 -15.056,9.2226027 -15.056,0 c 0,-9.2226027 6.7408009,-16.698999 15.056,-16.698999 8.3151991,0 15.056,7.4763963 15.056,16.698999 z" />
            <ellipse
               id="ellipse3128"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,441.376,449.718)"
               ry="9.2309999"
               rx="8.323"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="8.323"
               sodipodi:ry="9.2309999"
               style="fill:#ffffff"
               d="M 8.323,0 C 8.323,5.0981405 4.5966659,9.2309999 0,9.2309999 -4.5966659,9.2309999 -8.323,5.0981405 -8.323,0 c 0,-5.0981405 3.7263341,-9.2309999 8.323,-9.2309999 4.5966659,0 8.323,4.1328594 8.323,9.2309999 z" />
            <ellipse
               id="ellipse3130"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,465.008,428.783)"
               ry="5.7420001"
               rx="5.177"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="5.177"
               sodipodi:ry="5.7420001"
               style="fill:#ffffff"
               d="M 5.177,0 C 5.177,3.1712191 2.8591782,5.7420001 0,5.7420001 -2.8591782,5.7420001 -5.177,3.1712191 -5.177,0 c 0,-3.1712191 2.3178218,-5.7420001 5.177,-5.7420001 2.8591782,0 5.177,2.570781 5.177,5.7420001 z" />
          </g>
          <g
             id="Group_5"
             style="stroke-width:1.09769905">
            <path
               id="path3133"
               stroke-miterlimit="79.8403193612775"
               d="m 284.077,218.02 c -11.626,2.35 -22.178,7.06 -31.546,13.935 -2.452,1.799 -4.826,3.759 -7.104,5.915 -5.571,5.269 -10.085,11.108 -13.562,17.451 -3.394,6.189 -5.769,12.908 -6.968,20.193 -0.511,3.101 -0.793,6.312 -0.822,9.659 -0.057,6.342 0.817,12.256 2.343,17.818 0.42,1.531 0.899,3.036 1.435,4.511 0.289,0.797 0.587,1.603 0.947,2.367 0.222,0.472 0.51,0.915 0.782,1.363 -0.042,-0.348 -0.075,-0.698 -0.126,-1.043 -0.138,-0.931 -0.399,-1.821 -0.61,-2.723 -0.372,-1.589 -0.726,-3.184 -1.036,-4.799 -0.895,-4.653 -1.437,-9.486 -1.402,-14.594 0.049,-7.182 1.231,-13.824 3.335,-19.982 2.014,-5.898 4.855,-11.39 8.49,-16.48 1.518,-2.128 3.183,-4.198 4.986,-6.183 4.58,-5.045 9.792,-9.298 15.269,-12.755 5.162,-3.26 10.676,-5.868 16.492,-7.831 2.646,-0.894 5.363,-1.653 8.152,-2.261 4.274,-0.933 8.713,-1.532 13.376,-1.693 4.198,-0.146 8.365,0.091 12.283,0.644 5.193,0.732 10.126,2.042 14.784,3.855 6.071,2.362 11.736,5.596 16.928,9.719 1.277,1.014 2.529,2.074 3.757,3.194 6.153,5.612 11.032,12.078 14.981,18.872 3.893,6.698 6.899,13.862 9.274,21.323 5.538,17.404 7.579,36.578 7.568,56.749 -0.004,5.759 -0.187,11.428 -0.462,17.054 -0.128,2.614 -0.285,5.22 -0.437,7.823 -0.069,1.169 -0.134,2.339 -0.193,3.516 -0.018,0.345 -0.048,0.666 -0.051,1.012 -0.008,0.859 0.053,1.728 0.081,2.586 0.229,-0.829 0.502,-1.659 0.693,-2.496 0.186,-0.821 0.305,-1.672 0.442,-2.501 0.322,-1.956 0.595,-3.93 0.845,-5.916 0.319,-2.542 0.6,-5.108 0.843,-7.692 0.439,-4.673 0.734,-9.418 0.902,-14.227 0.248,-7.138 0.16,-14.481 -0.296,-21.466 -0.772,-11.792 -2.56,-23.093 -5.609,-33.746 -3.274,-11.436 -8.002,-22.217 -14.869,-31.854 -1.998,-2.803 -4.182,-5.521 -6.6,-8.114 -7.325,-7.855 -15.771,-13.722 -25.169,-17.545 -4.127,-1.679 -8.444,-2.984 -12.969,-3.86 -3.567,-0.691 -7.267,-1.131 -11.109,-1.278 -6.282,-0.242 -12.369,0.331 -18.048,1.48 z"
               inkscape:connector-curvature="0"
               style="fill:#402100;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
            <path
               id="path3135"
               stroke-miterlimit="79.8403193612775"
               d="m 449.276,221.873 c -3.186,0.278 -6.269,0.767 -9.252,1.451 -8.853,2.027 -16.92,5.64 -24.203,10.802 -2.58,1.828 -5.059,3.844 -7.439,6.068 -6.475,6.048 -11.536,12.926 -15.6,20.239 -4.47,8.041 -7.785,16.693 -10.188,25.768 -3.887,14.673 -5.565,30.498 -5.42,47.178 0.024,2.812 0.09,5.596 0.211,8.362 0.232,5.347 0.628,10.62 1.189,15.807 0.283,2.623 0.607,5.23 0.991,7.808 0.174,1.17 0.364,2.335 0.567,3.487 0.062,0.356 0.096,0.646 0.176,1 0.189,0.838 0.461,1.669 0.691,2.497 0.033,-1.031 0.089,-2.067 0.06,-3.091 -0.044,-1.512 -0.156,-3.017 -0.241,-4.521 -0.112,-1.958 -0.226,-3.913 -0.325,-5.875 -0.353,-6.952 -0.569,-13.992 -0.515,-21.138 0.094,-12.72 1.066,-25.029 3.214,-36.731 1.712,-9.332 4.167,-18.284 7.605,-26.752 2.669,-6.576 5.96,-12.831 10.043,-18.694 3.152,-4.527 6.906,-8.893 11.183,-12.752 1.326,-1.197 2.679,-2.326 4.07,-3.396 5.428,-4.18 11.355,-7.431 17.748,-9.687 4.975,-1.756 10.237,-2.955 15.832,-3.463 3.132,-0.285 6.49,-0.366 9.728,-0.206 2.979,0.146 5.869,0.473 8.68,0.957 6.098,1.05 11.842,2.812 17.282,5.185 5.143,2.243 10.015,5.024 14.596,8.4 3.479,2.564 6.826,5.504 9.9,8.783 2.708,2.889 5.116,5.946 7.206,9.149 6.884,10.549 10.778,22.756 10.429,36.879 -0.097,3.88 -0.51,7.594 -1.139,11.208 -0.309,1.768 -0.67,3.521 -1.067,5.25 -0.188,0.816 -0.378,1.629 -0.563,2.447 -0.056,0.245 -0.126,0.494 -0.168,0.743 -0.073,0.428 -0.101,0.869 -0.149,1.301 0.222,-0.373 0.476,-0.741 0.673,-1.127 0.153,-0.301 0.27,-0.632 0.4,-0.944 0.258,-0.625 0.494,-1.258 0.72,-1.898 0.704,-2.007 1.305,-4.061 1.814,-6.166 1.345,-5.579 2.045,-11.638 1.791,-17.933 -0.279,-6.89 -1.597,-13.271 -3.768,-19.217 -1.972,-5.398 -4.604,-10.45 -7.895,-15.189 -3.189,-4.592 -7.114,-9.006 -11.486,-12.854 -2.385,-2.099 -4.845,-4.016 -7.406,-5.763 -5.289,-3.608 -10.906,-6.509 -16.877,-8.755 -5.263,-1.98 -10.821,-3.422 -16.672,-4.214 -5.216,-0.707 -11.011,-0.877 -16.426,-0.403 z"
               inkscape:connector-curvature="0"
               style="fill:#402100;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
          </g>
          <path
             id="path3137"
             stroke-miterlimit="79.8403193612775"
             d="m 161.756,482.447 c -0.021,0.221 -0.071,0.414 -0.058,0.636 0.004,0.086 0.047,0.168 0.06,0.255 0.047,0.338 0.156,0.692 0.244,1.023 0.256,0.963 0.578,1.908 0.886,2.848 0.411,1.257 0.834,2.51 1.24,3.772 1.379,4.289 2.576,8.663 3.169,13.345 0.316,2.498 0.451,5.222 0.262,7.843 -0.141,1.934 -0.444,3.774 -0.909,5.537 -0.65,2.459 -1.664,4.778 -3.106,6.839 -0.651,0.929 -1.377,1.81 -2.215,2.649 -1.377,1.376 -2.91,2.47 -4.552,3.319 -3.263,1.686 -6.961,2.491 -11.077,2.461 -1.338,-0.011 -2.635,-0.113 -3.897,-0.278 -5.704,-0.75 -10.833,-2.76 -15.684,-5.227 -2.496,-1.27 -4.905,-2.687 -7.305,-4.142 -1.054,-0.639 -2.103,-1.295 -3.167,-1.91 -0.494,-0.286 -0.993,-0.566 -1.504,-0.818 -0.168,-0.083 -0.276,-0.156 -0.45,-0.222 -0.078,-0.03 -0.146,-0.089 -0.225,-0.111 -0.099,-0.028 -0.205,-0.02 -0.304,-0.04 -0.397,-0.081 -0.815,-0.106 -1.216,-0.157 0.047,0.304 0.096,0.61 0.144,0.915 0.034,0.216 0.026,0.402 0.096,0.61 0.026,0.08 0.092,0.145 0.127,0.223 0.133,0.302 0.335,0.614 0.512,0.895 0.519,0.827 1.135,1.615 1.773,2.379 0.854,1.023 1.767,2.014 2.744,2.981 3.666,3.627 7.75,6.51 12.11,8.756 4.901,2.525 10.276,4.248 16.271,4.567 3.08,0.163 6.12,-0.112 8.867,-0.768 5.122,-1.225 9.71,-3.693 13.444,-7.666 0.969,-1.033 1.832,-2.122 2.597,-3.255 2.391,-3.544 3.889,-7.528 4.574,-11.924 0.477,-3.07 0.506,-6.56 0.138,-9.703 -0.427,-3.643 -1.298,-7.044 -2.479,-10.309 -1.147,-3.167 -2.61,-6.205 -4.367,-9.066 -0.643,-1.047 -1.325,-2.079 -2.067,-3.076 -0.816,-1.095 -1.691,-2.166 -2.717,-3.137 -0.563,-0.533 -1.195,-0.712 -1.87,-0.997 -0.03,0.317 -0.06,0.635 -0.089,0.953 z"
             inkscape:connector-curvature="0"
             style="fill:#402100;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
          <path
             id="path3139"
             stroke-miterlimit="79.8403193612775"
             d="m 364.339,488.047 c -0.268,0.016 -0.514,0.012 -0.779,0.049 -0.128,0.017 -0.263,-0.002 -0.389,0.025 -0.14,0.029 -0.27,0.103 -0.407,0.142 -0.549,0.153 -1.089,0.381 -1.625,0.571 0.356,0.237 0.713,0.475 1.07,0.713 0.263,0.175 0.431,0.332 0.714,0.476 0.253,0.128 0.457,0.16 0.725,0.255 2.531,0.891 5.149,1.608 7.744,2.371 5.04,1.481 10.041,3.039 14.882,4.922 3.991,1.552 7.876,3.291 11.622,5.328 1.917,1.042 3.796,2.17 5.617,3.401 5.987,4.046 12.002,9.674 14.438,16.462 0.762,2.125 1.253,4.439 1.17,6.972 -0.027,0.798 -0.112,1.58 -0.234,2.332 -0.385,2.364 -1.235,4.492 -2.36,6.492 -1.557,2.764 -3.788,5.316 -6.298,7.524 -2.513,2.209 -5.213,4.055 -8.024,5.67 -2.896,1.663 -5.906,3.104 -8.995,4.374 -7.138,2.934 -14.685,4.991 -22.377,6.821 -1.957,0.465 -3.926,0.907 -5.879,1.39 -0.901,0.222 -1.804,0.454 -2.687,0.712 -0.285,0.082 -0.498,0.124 -0.776,0.226 -0.126,0.045 -0.266,0.059 -0.388,0.113 -0.138,0.06 -0.256,0.158 -0.389,0.227 -0.531,0.271 -1.038,0.608 -1.552,0.91 0.42,0.165 0.839,0.33 1.26,0.496 0.311,0.122 0.516,0.249 0.841,0.331 0.131,0.033 0.273,0.018 0.407,0.043 0.281,0.05 0.53,0.056 0.815,0.087 1.663,0.177 3.431,0.217 5.176,0.2 2.32,-0.024 4.577,-0.149 6.814,-0.341 7.896,-0.682 15.384,-2.272 22.421,-4.677 2.973,-1.017 5.865,-2.214 8.649,-3.611 4.192,-2.106 8.141,-4.633 11.757,-7.891 3.522,-3.175 6.378,-6.872 8.222,-10.948 1.401,-3.099 2.318,-6.458 2.437,-10.2 0.072,-2.27 -0.177,-4.44 -0.617,-6.475 -0.273,-1.26 -0.639,-2.479 -1.078,-3.655 -1.891,-5.059 -5.06,-9.464 -9.177,-13.398 -0.574,-0.548 -1.159,-1.07 -1.75,-1.579 -3.136,-2.701 -6.522,-4.935 -10.052,-6.852 -2.477,-1.346 -5.028,-2.538 -7.65,-3.595 -3.602,-1.452 -7.33,-2.66 -11.169,-3.645 -4.354,-1.118 -8.856,-1.945 -13.524,-2.437 -1.93,-0.204 -3.909,-0.351 -5.914,-0.384 -0.904,-0.015 -1.821,-0.002 -2.691,0.053 z"
             inkscape:connector-curvature="0"
             style="fill:#402100;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
          <path
             id="path3141"
             stroke-miterlimit="79.8403193612775"
             d="m 346.929,500.715 c -0.224,0.024 -0.421,0.026 -0.641,0.071 -0.105,0.021 -0.218,0.006 -0.32,0.036 -0.119,0.034 -0.222,0.109 -0.337,0.153 -0.458,0.17 -0.9,0.411 -1.344,0.615 0.287,0.229 0.575,0.458 0.863,0.687 0.209,0.166 0.345,0.321 0.576,0.459 0.201,0.12 0.37,0.147 0.589,0.234 2.04,0.81 4.174,1.443 6.291,2.103 4.075,1.271 8.137,2.562 12.073,4.105 3.719,1.458 7.354,3.09 10.807,5.075 1.154,0.663 2.291,1.363 3.405,2.113 3.743,2.52 7.573,5.862 9.857,9.808 1.334,2.305 2.293,4.934 2.135,7.947 -0.017,0.322 -0.043,0.636 -0.082,0.948 -0.063,0.488 -0.147,0.959 -0.26,1.42 -0.351,1.419 -0.912,2.716 -1.626,3.954 -1.224,2.117 -2.996,4.078 -4.937,5.742 -4.098,3.51 -8.805,5.937 -13.669,7.928 -5.806,2.375 -11.941,4.069 -18.147,5.656 -1.599,0.408 -3.199,0.799 -4.782,1.236 -0.735,0.202 -1.47,0.417 -2.187,0.658 -0.234,0.078 -0.406,0.115 -0.632,0.212 -0.103,0.043 -0.218,0.055 -0.316,0.107 -0.114,0.059 -0.206,0.155 -0.315,0.222 -0.435,0.266 -0.844,0.594 -1.26,0.888 0.346,0.172 0.692,0.345 1.038,0.518 0.258,0.129 0.418,0.255 0.693,0.346 0.106,0.035 0.225,0.024 0.334,0.051 0.233,0.056 0.431,0.066 0.669,0.103 1.361,0.209 2.801,0.285 4.252,0.312 1.887,0.033 3.765,-0.023 5.601,-0.142 6.518,-0.426 12.679,-1.624 18.477,-3.496 6.158,-1.99 11.974,-4.826 16.961,-9.155 2.944,-2.557 5.383,-5.601 6.947,-8.939 1.201,-2.566 1.991,-5.355 2.091,-8.465 0.06,-1.894 -0.151,-3.697 -0.53,-5.388 -1.355,-6.045 -5.234,-11.165 -10.136,-15.228 -2.609,-2.163 -5.427,-3.945 -8.361,-5.466 -2.053,-1.065 -4.165,-2.005 -6.336,-2.831 -2.978,-1.134 -6.051,-2.061 -9.222,-2.81 -3.581,-0.847 -7.295,-1.449 -11.14,-1.75 -1.587,-0.125 -3.211,-0.207 -4.865,-0.173 -0.744,0.014 -1.5,0.056 -2.214,0.136 z"
             inkscape:connector-curvature="0"
             style="fill:#402100;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
          <path
             id="path3143"
             stroke-miterlimit="79.8403193612775"
             d="m 326.879,510.084 c -0.201,0.03 -0.371,0.036 -0.567,0.087 -0.093,0.023 -0.194,0.012 -0.283,0.044 -0.107,0.037 -0.196,0.115 -0.299,0.162 -0.409,0.183 -0.8,0.434 -1.192,0.649 0.252,0.224 0.504,0.448 0.757,0.673 0.182,0.162 0.301,0.316 0.506,0.45 0.174,0.114 0.325,0.138 0.518,0.221 1.783,0.761 3.663,1.339 5.534,1.933 3.568,1.131 7.14,2.254 10.613,3.57 3.251,1.231 6.436,2.603 9.474,4.258 1.791,0.975 3.544,2.049 5.209,3.272 2.799,2.055 5.569,4.723 7.017,7.81 0.659,1.405 1.086,3.013 0.955,4.771 -0.018,0.232 -0.046,0.469 -0.081,0.696 -0.045,0.283 -0.106,0.568 -0.178,0.839 -0.29,1.086 -0.745,2.063 -1.321,3.003 -1.046,1.704 -2.597,3.28 -4.198,4.572 -3.599,2.902 -7.706,4.881 -11.925,6.545 -5.129,2.021 -10.528,3.461 -15.952,4.887 -1.41,0.37 -2.82,0.729 -4.211,1.14 -0.65,0.191 -1.296,0.394 -1.925,0.625 -0.206,0.075 -0.36,0.11 -0.557,0.204 -0.089,0.041 -0.194,0.053 -0.278,0.103 -0.102,0.058 -0.181,0.152 -0.277,0.219 -0.386,0.264 -0.742,0.588 -1.107,0.88 0.306,0.179 0.612,0.358 0.919,0.537 0.227,0.133 0.367,0.261 0.613,0.358 0.093,0.036 0.199,0.028 0.295,0.057 0.207,0.06 0.378,0.073 0.591,0.114 1.198,0.231 2.474,0.334 3.759,0.392 1.632,0.073 3.322,0.062 4.954,-0.006 5.765,-0.243 11.226,-1.178 16.362,-2.686 5.472,-1.607 10.643,-3.941 15.115,-7.549 2.605,-2.103 4.889,-4.735 6.317,-7.595 0.951,-1.906 1.637,-3.957 1.861,-6.228 0.506,-5.16 -1.264,-9.593 -4.025,-13.265 -0.525,-0.698 -1.093,-1.374 -1.701,-2.03 -2.938,-3.168 -6.383,-5.485 -9.99,-7.364 -1.76,-0.917 -3.571,-1.704 -5.432,-2.419 -3.117,-1.198 -6.38,-2.118 -9.746,-2.816 -3.171,-0.658 -6.455,-1.111 -9.861,-1.282 -1.408,-0.072 -2.884,-0.1 -4.304,-0.024 -0.66,0.035 -1.328,0.096 -1.959,0.193 z"
             inkscape:connector-curvature="0"
             style="fill:#402100;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
          <g
             id="Group_6"
             style="stroke:none">
            <ellipse
               id="ellipse3146"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,378.137,372.359)"
               ry="67.042"
               rx="40.488998"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="40.488998"
               sodipodi:ry="67.042"
               style="fill:#000000"
               d="M 40.488998,0 C 40.488998,37.026274 22.361456,67.042 0,67.042 -22.361456,67.042 -40.488998,37.026274 -40.488998,0 c 0,-37.026274 18.127542,-67.042 40.488998,-67.042 22.361456,0 40.488998,30.015726 40.488998,67.042 z" />
            <ellipse
               id="ellipse3148"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,378.334,377.333)"
               ry="54.855"
               rx="33.129002"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="33.129002"
               sodipodi:ry="54.855"
               style="fill:#1d1c1b"
               d="M 33.129002,0 C 33.129002,30.29558 18.296642,54.855 0,54.855 -18.296642,54.855 -33.129002,30.29558 -33.129002,0 c 0,-30.29558 14.83236,-54.855 33.129002,-54.855 18.296642,0 33.129002,24.55942 33.129002,54.855 z" />
            <ellipse
               id="ellipse3150"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,408.294,385.083)"
               ry="13.173"
               rx="9.7069998"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="9.7069998"
               sodipodi:ry="13.173"
               style="fill:#fffcf9"
               d="M 9.7069998,0 C 9.7069998,7.2752472 5.3610279,13.173 0,13.173 -5.3610279,13.173 -9.7069998,7.2752472 -9.7069998,0 c 0,-7.2752472 4.3459719,-13.173 9.7069998,-13.173 5.3610279,0 9.7069998,5.8977528 9.7069998,13.173 z" />
            <ellipse
               id="ellipse3152"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(0,1,-1,0,423.924,362.907)"
               ry="2.8540001"
               rx="2.5929999"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="2.5929999"
               sodipodi:ry="2.8540001"
               style="fill:#fefefe"
               d="M 2.5929999,0 C 2.5929999,1.5762207 1.4320743,2.8540001 0,2.8540001 -1.4320743,2.8540001 -2.5929999,1.5762207 -2.5929999,0 c 0,-1.5762207 1.1609256,-2.8540001 2.5929999,-2.8540001 1.4320743,0 2.5929999,1.2777794 2.5929999,2.8540001 z" />
          </g>
          <g
             stroke-miterlimit="79.8403193612775"
             id="Group_7"
             style="fill:#a95b09;stroke:none">
            <ellipse
               id="ellipse3155"
               transform="matrix(0,1,-1,0,285.947,366.272)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
            <ellipse
               id="ellipse3157"
               transform="matrix(0,1,-1,0,265.537,359.468)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
            <ellipse
               id="ellipse3159"
               transform="matrix(0,1,-1,0,300.384,356.15)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
            <ellipse
               id="ellipse3161"
               transform="matrix(0,1,-1,0,282.462,344.533)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
          </g>
          <g
             stroke-miterlimit="79.8403193612775"
             id="Group_8"
             style="fill:#a95b09;stroke:none">
            <ellipse
               id="ellipse3164"
               transform="matrix(0,1,-1,0,479.116,368.252)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
            <ellipse
               id="ellipse3166"
               transform="matrix(0,1,-1,0,458.704,361.448)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
            <ellipse
               id="ellipse3168"
               transform="matrix(0,1,-1,0,493.552,358.13)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
            <ellipse
               id="ellipse3170"
               transform="matrix(0,1,-1,0,475.63,346.514)"
               ry="3.487"
               rx="3.1530001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="3.1530001"
               sodipodi:ry="3.487"
               d="M 3.1530001,0 C 3.1530001,1.9258169 1.7413539,3.487 0,3.487 -1.7413539,3.487 -3.1530001,1.9258169 -3.1530001,0 c 0,-1.9258169 1.4116462,-3.487 3.1530001,-3.487 1.7413539,0 3.1530001,1.5611831 3.1530001,3.487 z" />
          </g>
          <path
             id="path3172"
             stroke-miterlimit="79.8403193612775"
             d="m 379.946,182.419 c -2.208,0.227 -4.336,0.635 -6.389,1.181 -3.628,0.963 -7.035,2.39 -10.207,4.268 -2.893,1.711 -5.604,3.807 -8.066,6.363 -2.254,2.339 -4.136,4.87 -5.617,7.595 -0.333,0.611 -0.644,1.237 -0.93,1.871 -0.178,0.392 -0.361,0.788 -0.472,1.215 -0.057,0.215 -0.097,0.437 -0.144,0.656 0.828,-0.962 1.433,-1.99 2.135,-3.012 1.138,-1.66 2.375,-3.258 3.753,-4.798 3.895,-4.357 8.522,-7.609 13.549,-9.84 2.537,-1.127 5.211,-1.991 8.01,-2.596 2.215,-0.48 4.515,-0.783 6.914,-0.888 3.999,-0.177 7.863,0.232 11.409,1.092 3.529,0.855 6.83,2.159 9.9,3.937 2.944,1.704 5.735,3.878 8.165,6.538 2.399,2.626 4.276,5.49 5.789,8.568 0.288,0.587 0.563,1.177 0.831,1.777 0.271,0.608 0.504,1.252 0.811,1.843 0.124,0.239 0.281,0.466 0.42,0.698 -0.011,-0.27 0,-0.55 -0.032,-0.818 -0.031,-0.256 -0.103,-0.523 -0.161,-0.774 -0.143,-0.611 -0.318,-1.218 -0.511,-1.805 -0.275,-0.833 -0.574,-1.643 -0.912,-2.442 -1.315,-3.101 -3.104,-5.944 -5.371,-8.568 -2.763,-3.197 -6.093,-5.749 -9.601,-7.644 -5.824,-3.147 -12.519,-4.83 -19.975,-4.635 -1.124,0.029 -2.216,0.106 -3.298,0.218 z"
             inkscape:connector-curvature="0"
             style="fill:#ffc17f;fill-rule:evenodd;stroke:none;stroke-width:0.5;marker-start:none;marker-end:none" />
          <g
             id="Group_9"
             style="stroke:none">
            <g
               id="Group_10">
              <g
                 id="Group_11"
                 style="fill:#7f007e">
                <ellipse
                   id="ellipse3177"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(-0.32581568,0.94543331,-1.0135217,-0.12824065,320.283,114.984)"
                   ry="54.530998"
                   rx="56.332001"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="56.332001"
                   sodipodi:ry="54.530998"
                   d="M 56.332001,0 C 56.332001,30.116639 31.111305,54.530998 0,54.530998 -31.111305,54.530998 -56.332001,30.116639 -56.332001,0 c 0,-30.116639 25.220696,-54.530998 56.332001,-54.530998 31.111305,0 56.332001,24.414359 56.332001,54.530998 z" />
                <ellipse
                   id="ellipse3179"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(0.86805501,0.49646802,-0.94902689,0.60922233,323.843,69.278)"
                   ry="29.478001"
                   rx="54.299"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="54.299"
                   sodipodi:ry="29.478001"
                   d="M 54.299,0 C 54.299,16.28025 29.98851,29.478001 0,29.478001 -29.98851,29.478001 -54.299,16.28025 -54.299,0 c 0,-16.28025 24.31049,-29.478001 54.299,-29.478001 29.98851,0 54.299,13.197751 54.299,29.478001 z" />
              </g>
              <g
                 id="Group_12"
                 style="fill:#bf00bd">
                <ellipse
                   id="ellipse3182"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(-0.32581568,0.94543331,-1.0135259,-0.1282286,325.023,113.982)"
                   ry="47.827999"
                   rx="49.408001"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="49.408001"
                   sodipodi:ry="47.827999"
                   d="M 49.408001,0 C 49.408001,26.414675 27.287285,47.827999 0,47.827999 -27.287285,47.827999 -49.408001,26.414675 -49.408001,0 c 0,-26.414675 22.120716,-47.827999 49.408001,-47.827999 27.287285,0 49.408001,21.413324 49.408001,47.827999 z" />
                <ellipse
                   id="ellipse3184"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(0.86805328,0.49647105,-0.94903672,0.60921461,328.144,73.893)"
                   ry="25.854"
                   rx="47.625999"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="47.625999"
                   sodipodi:ry="25.854"
                   d="M 47.625999,0 C 47.625999,14.27877 26.303113,25.854 0,25.854 -26.303113,25.854 -47.625999,14.27877 -47.625999,0 c 0,-14.27877 21.322886,-25.854 47.625999,-25.854 26.303113,0 47.625999,11.57523 47.625999,25.854 z" />
              </g>
              <g
                 id="Group_13"
                 style="fill:#7f007e">
                <ellipse
                   id="ellipse3187"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(-0.32576618,0.94545037,-1.0135148,-0.12822719,336.966,108.723)"
                   ry="38.631001"
                   rx="39.908001"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="39.908001"
                   sodipodi:ry="38.631001"
                   d="M 39.908001,0 C 39.908001,21.335312 22.04058,38.631001 0,38.631001 -22.04058,38.631001 -39.908001,21.335312 -39.908001,0 c 0,-21.335312 17.867421,-38.631001 39.908001,-38.631001 22.04058,0 39.908001,17.295689 39.908001,38.631001 z" />
                <ellipse
                   id="ellipse3189"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(0.86806541,0.49644984,-0.94900064,0.60924992,339.488,76.344)"
                   ry="20.882999"
                   rx="38.466999"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="38.466999"
                   sodipodi:ry="20.882999"
                   d="M 38.466999,0 C 38.466999,11.533362 21.244737,20.882999 0,20.882999 -21.244737,20.882999 -38.466999,11.533362 -38.466999,0 c 0,-11.533362 17.222262,-20.882999 38.466999,-20.882999 21.244737,0 38.466999,9.349637 38.466999,20.882999 z" />
              </g>
            </g>
            <g
               id="Group_14">
              <g
                 id="Group_15"
                 style="fill:#7f007e">
                <ellipse
                   id="ellipse3193"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(0.32581403,0.94543388,-1.0135219,0.12823888,450.125,115.425)"
                   ry="54.530998"
                   rx="56.332001"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="56.332001"
                   sodipodi:ry="54.530998"
                   d="M 56.332001,0 C 56.332001,30.116639 31.111305,54.530998 0,54.530998 -31.111305,54.530998 -56.332001,30.116639 -56.332001,0 c 0,-30.116639 25.220696,-54.530998 56.332001,-54.530998 31.111305,0 56.332001,24.414359 56.332001,54.530998 z" />
                <ellipse
                   id="ellipse3195"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(-0.86805155,0.49647408,-0.94903114,-0.60921571,446.563,69.718)"
                   ry="29.478001"
                   rx="54.299"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="54.299"
                   sodipodi:ry="29.478001"
                   d="M 54.299,0 C 54.299,16.28025 29.98851,29.478001 0,29.478001 -29.98851,29.478001 -54.299,16.28025 -54.299,0 c 0,-16.28025 24.31049,-29.478001 54.299,-29.478001 29.98851,0 54.299,13.197751 54.299,29.478001 z" />
              </g>
              <g
                 id="Group_16"
                 style="fill:#bf00bd">
                <ellipse
                   id="ellipse3198"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(0.32581733,0.94543274,-1.0135256,0.12823037,445.384,114.422)"
                   ry="47.827999"
                   rx="49.408001"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="49.408001"
                   sodipodi:ry="47.827999"
                   d="M 49.408001,0 C 49.408001,26.414675 27.287285,47.827999 0,47.827999 -27.287285,47.827999 -49.408001,26.414675 -49.408001,0 c 0,-26.414675 22.120716,-47.827999 49.408001,-47.827999 27.287285,0 49.408001,21.413324 49.408001,47.827999 z" />
                <ellipse
                   id="ellipse3200"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(-0.86805155,0.49647408,-0.94903885,-0.6092113,442.263,74.333)"
                   ry="25.854"
                   rx="47.625999"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="47.625999"
                   sodipodi:ry="25.854"
                   d="M 47.625999,0 C 47.625999,14.27877 26.303113,25.854 0,25.854 -26.303113,25.854 -47.625999,14.27877 -47.625999,0 c 0,-14.27877 21.322886,-25.854 47.625999,-25.854 26.303113,0 47.625999,11.57523 47.625999,25.854 z" />
              </g>
              <g
                 id="Group_17"
                 style="fill:#7f007e">
                <ellipse
                   id="ellipse3203"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(0.32577443,0.94544753,-1.0135137,0.12823604,433.443,109.163)"
                   ry="38.631001"
                   rx="39.908001"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="39.908001"
                   sodipodi:ry="38.631001"
                   d="M 39.908001,0 C 39.908001,21.335312 22.04058,38.631001 0,38.631001 -22.04058,38.631001 -39.908001,21.335312 -39.908001,0 c 0,-21.335312 17.867421,-38.631001 39.908001,-38.631001 22.04058,0 39.908001,17.295689 39.908001,38.631001 z" />
                <ellipse
                   id="ellipse3205"
                   stroke-miterlimit="79.8403193612775"
                   transform="matrix(-0.86806888,0.49644378,-0.94899639,-0.60925655,430.918,76.785)"
                   ry="20.882999"
                   rx="38.466999"
                   cx="0"
                   cy="0"
                   sodipodi:cx="0"
                   sodipodi:cy="0"
                   sodipodi:rx="38.466999"
                   sodipodi:ry="20.882999"
                   d="M 38.466999,0 C 38.466999,11.533362 21.244737,20.882999 0,20.882999 -21.244737,20.882999 -38.466999,11.533362 -38.466999,0 c 0,-11.533362 17.222262,-20.882999 38.466999,-20.882999 21.244737,0 38.466999,9.349637 38.466999,20.882999 z" />
              </g>
            </g>
            <ellipse
               id="ellipse3207"
               stroke-miterlimit="79.8403193612775"
               transform="matrix(1.1868239e-4,0.99999999,-0.99999999,1.1868239e-4,381.9,96.99)"
               ry="23.136999"
               rx="16.822001"
               cx="0"
               cy="0"
               sodipodi:cx="0"
               sodipodi:cy="0"
               sodipodi:rx="16.822001"
               sodipodi:ry="23.136999"
               style="fill:#7f007e"
               d="M 16.822001,0 C 16.822001,12.778212 9.2905343,23.136999 0,23.136999 -9.2905343,23.136999 -16.822001,12.778212 -16.822001,0 c 0,-12.778212 7.5314667,-23.136999 16.822001,-23.136999 9.2905343,0 16.822001,10.358787 16.822001,23.136999 z" />
            <g
               id="Group_18">
              <ellipse
                 id="ellipse3210"
                 stroke-miterlimit="79.8403193612775"
                 transform="matrix(-2.5481807e-4,0.99999997,-0.99999997,-2.5481807e-4,382.656,97.431)"
                 ry="16.166"
                 rx="11.753"
                 cx="0"
                 cy="0"
                 sodipodi:cx="0"
                 sodipodi:cy="0"
                 sodipodi:rx="11.753"
                 sodipodi:ry="16.166"
                 style="fill:#bf00bd"
                 d="M 11.753,0 C 11.753,8.9282355 6.4910028,16.166 0,16.166 -6.4910028,16.166 -11.753,8.9282355 -11.753,0 c 0,-8.9282355 5.2619972,-16.166 11.753,-16.166 6.4910028,0 11.753,7.2377645 11.753,16.166 z" />
              <ellipse
                 id="ellipse3212"
                 stroke-miterlimit="79.8403193612775"
                 transform="matrix(0,1,-1,0,382.667,97.297)"
                 ry="12.191"
                 rx="8.8629999"
                 cx="0"
                 cy="0"
                 sodipodi:cx="0"
                 sodipodi:cy="0"
                 sodipodi:rx="8.8629999"
                 sodipodi:ry="12.191"
                 style="fill:#7f007e"
                 d="M 8.8629999,0 C 8.8629999,6.7329034 4.8948997,12.191 0,12.191 -4.8948997,12.191 -8.8629999,6.7329034 -8.8629999,0 c 0,-6.7329034 3.9681002,-12.191 8.8629999,-12.191 4.8948997,0 8.8629999,5.4580966 8.8629999,12.191 z" />
            </g>
          </g>
        </g>
      </g>
    </g>
  </g>
</svg>
    """


greenify : SvgAst -> SvgAst
greenify =
    SvgAst.changeAttribute ("stroke", SvgAst.Value "green")
        >> SvgAst.changeAttribute ("fill", SvgAst.Value "green")
        >> SvgAst.changeAttribute ("style", SvgAst.Value "fill:green")

change : List SvgAst -> List SvgAst
change xs =
    List.map (SvgAst.map greenify) xs

view : Model -> Html Msg
view model =
    Html.div []
        ([(svgString |> parse |> (R.withDefault [SvgAst.Comment "test"]) |> change |> show |> toHtml)] ++
        (svgString |> parse |> (R.withDefault [SvgAst.Comment "test"]) |> map render) ++
        (svgString |> parse |> (R.withDefault [SvgAst.Comment "test"]) |> change |> map render))

update : Msg -> Model -> Model
update msg model = model

main =
    Html.beginnerProgram
        { model = initialModel
        , view = view
        , update = update
        }

